@@ -13,6 +13,8 @@ from multiprocessing import AuthenticationError
 import OpenSSL.crypto
 import paho.mqtt.client as mqtt
 
+from pyworxcloud.clouds import CloudType
+
 from .day_map import DAY_MAP
 from .exceptions import (
     AuthorizationError,
@@ -42,21 +44,35 @@ class WorxCloud(object):
         self,
         username: str,
         password: str,
-        cloud_type: str = "worx",
-        index: int | None = None,
+        cloud: CloudType.WORX
+        | CloudType.KRESS
+        | CloudType.LANDXCAPE
+        | CloudType.FERREX
+        | str = CloudType.WORX,
+        index: int = 0,
         verify_ssl: bool = True,
     ) -> None:
         """Initialize WorxCloud object and set default attribute values."""
         self._worx_mqtt_client_id = None
         self._worx_mqtt_endpoint = None
 
-        self._api = LandroidAPI()
+        if not isinstance(
+            cloud,
+            (
+                type(CloudType.WORX),
+                type(CloudType.KRESS),
+                type(CloudType.LANDXCAPE),
+                type(CloudType.FERREX),
+            ),
+        ):
+            try:
+                cloud = getattr(CloudType, cloud.upper())
+            except AttributeError:
+                raise TypeError(
+                    "Wrong type specified, valid types are: worx, landxcape, kress, ferrex"
+                )
 
-        self._api.password = password
-        self._api.type = (
-            cloud_type  # Usable cloud_types are: worx, kress and landxcape.
-        )
-        self._api.username = username
+        self._api = LandroidAPI(username, password, cloud)
 
         self._auth_result = False
         self._callback = None  # Callback used when data arrives from cloud
@@ -79,7 +95,7 @@ class WorxCloud(object):
         self.blade_time = 0
         self.blade_time_current = 0
         self.blade_work_time_reset = None
-        self.board = None
+        self.board = []
         self.current_zone = 0
         self.distance = 0
         self.error = None
@@ -90,6 +106,7 @@ class WorxCloud(object):
         self.locked = False
         self.mac = None
         self.mac_address = None
+        self.model = "Unknown"
         self.mowing_zone = 0
         self.mqtt_in = None
         self.mqtt_out = None
@@ -99,6 +116,7 @@ class WorxCloud(object):
         self.partymode_capable = False
         self.partymode_enabled = False
         self.pitch = 0
+        self.product = []
         self.rain_delay = None
         self.rain_delay_time_remaining = None
         self.rain_sensor_triggered = None
@@ -107,7 +125,6 @@ class WorxCloud(object):
         self.schedule_mower_active = False
         self.schedule_variation = None
         self.schedules = {}
-        self.serial = None
         self.serial_number = None
         self.status = None
         self.status_description = None
@@ -162,6 +179,8 @@ class WorxCloud(object):
                 self._dev_id = index
 
         self._get_mac_address()
+        self.product = self._api.get_product_info(self.product_id)
+        self.model = f'{self.product["default_name"]}{self.product["meters"]}'
 
         self._mqtt = mqtt.Client(self._worx_mqtt_client_id, protocol=mqtt.MQTTv311)
 
@@ -228,7 +247,7 @@ class WorxCloud(object):
         self.mqtt_out = self.mqtt_topics["command_out"]
         self.mqtt_in = self.mqtt_topics["command_in"]
         self.mac = self.mac_address
-        self.board = self.mqtt_out.split("/")[0]
+        self.board = self._api.get_board(self.mqtt_out.split("/")[0])
 
     def _forward_on_message(
         self, client, userdata, message
